feast.infra.registry.contrib.postgres package
=============================================

Submodules
----------

feast.infra.registry.contrib.postgres.postgres\_registry\_store module
----------------------------------------------------------------------

.. automodule:: feast.infra.registry.contrib.postgres.postgres_registry_store
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: feast.infra.registry.contrib.postgres
   :members:
   :undoc-members:
   :show-inheritance:
